@@ -1,7 +1,7 @@
 package Data::Verifier;
 use Moose;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use Data::Verifier::Filters;
 use Data::Verifier::Results;
@@ -42,24 +42,50 @@ sub verify {
             $val = $self->_filter_value($fprof->{filters}, $val);
         }
 
+        # Empty strings are undefined
+        if(defined($val) && $val eq '') {
+            $val = undef;
+        }
+
         # If the param is required, verify that it's there
         if($fprof->{required}) {
-            $results->set_missing($key, 1) unless defined($params->{$key});
+            $results->set_missing($key, 1) unless defined($val);
         }
 
         # Set the value
         $results->set_value($key, $val);
 
+        # No sense in continuing if the value isn't defined.
+        next unless defined($val);
+
+
+        # Check min length
+        if($fprof->{min_length} && length($val) < $fprof->{min_length}) {
+            $results->set_invalid($key, 1);
+            $results->set_value($key, undef);
+            next; # stop processing!
+        }
+
+        # Check max length
+        if($fprof->{max_length} && length($val) > $fprof->{max_length}) {
+            $results->set_invalid($key, 1);
+            $results->set_value($key, undef);
+            next; # stop processing!
+        }
+
         # Validate it
-        if($fprof->{type}) {
+        if(defined($val) && $fprof->{type}) {
             my $cons = Moose::Util::TypeConstraints::find_type_constraint($fprof->{type});
             die "Unknown type constraint '$cons'" unless defined($cons);
 
-            # if($fprof->{coerce}) {
-            #     $val = $cons->coerce($val);
-            # }
+            if($fprof->{coerce}) {
+                $val = $cons->coerce($val);
+            }
 
-            $results->set_invalid($key, 1) unless $cons->check($val);
+            unless($cons->check($val)) {
+                $results->set_invalid($key, 1);
+                $results->set_value($key, undef);
+            }
         }
     }
 
@@ -123,11 +149,14 @@ original idea) by leveraging the power of Moose's type constraint system.
     $results->success; # no
 
     $results->is_invalid('name'); # no
-    $results->is_invalid('age'); # yes
+    $results->is_invalid('age');  # yes
 
     $results->is_missing('name'); # no
     $results->is_missing('sign'); # yes
 
+    $results->get_value('name'); # Filtered, valid value
+    $results->get_value('age');  # undefined, as it's invalid
+
 =head1 MOTIVATION
 
 Data::Verifier firstly intends to leverage Moose's type constraint system,
@@ -155,12 +184,26 @@ are:
 
 =over 4
 
+=item coerce
+
+If true then the value will be given an opportunity to coerce via Moose's
+type system.
+
 =item filters
 
 An optional list of filters through which this specific value will be run. 
 See the documentation for L<Data::Verifier::Filters> to learn more.  This value
 may be either a string or an arrayref of strings.  
 
+=item max_length
+
+An optional length which the value may not exceed.
+
+
+=item min_length
+
+An optional length which the value may not be less.
+
 =item required
 
 Determines if this field is required for verification.
